==> haskell-network-2.7.0.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.7.0.2
id: network-2.7.0.2-rh9KFIvQth4GqHFEdJVEv
key: network-2.7.0.2-rh9KFIvQth4GqHFEdJVEv
license: BSD-3-Clause
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > library
    >   build-depends: network-uri-flag
category: Network
abi: 9f4c0094002519cc1dc579d0a3bd3879
exposed: True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
import-dirs: /usr/lib/ghc-8.4.3/site-local/network-2.7.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/network-2.7.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/network-2.7.0.2
hs-libraries: HSnetwork-2.7.0.2-rh9KFIvQth4GqHFEdJVEv
include-dirs: /usr/lib/ghc-8.4.3/site-local/network-2.7.0.2/include
includes:
    HsNet.h HsNetDef.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-2.7.0.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.7.0.2
id: network-2.7.0.2-Epka4Y5CXXTKVbAZSchnya
key: network-2.7.0.2-Epka4Y5CXXTKVbAZSchnya
license: BSD-3-Clause
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > library
    >   build-depends: network-uri-flag
category: Network
abi: 34c8f87548d66d5af3596a33ad5000fc
exposed: True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
import-dirs: /usr/lib/ghc-8.4.3/site-local/network-2.7.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/network-2.7.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/network-2.7.0.2
hs-libraries: HSnetwork-2.7.0.2-Epka4Y5CXXTKVbAZSchnya
include-dirs: /usr/lib/ghc-8.4.3/site-local/network-2.7.0.2/include
includes:
    HsNet.h HsNetDef.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
